import { render, waitFor } from "@testing-library/react";
import ApiInfo from "../ApiInfo";
import { getStatus } from "../../../domain/apiMethods";

jest.mock("../../../domain/apiMethods");

describe("ApiInfo", () => {
  it("renders and matches snapshot", () => {
    getStatus.mockResolvedValue(null);
    const { container } = render(<ApiInfo />);
    expect(container.firstChild).toMatchSnapshot();
  });

  it("renders and matches healthy snapshot", async () => {
    getStatus.mockResolvedValue({
      status: "healthy",
      version: "test",
    });
    const { container, getByText } = render(<ApiInfo />);
    await waitFor(() =>
      expect(getByText("API Version: test")).toBeInTheDocument()
    );
    expect(container.firstChild).toMatchSnapshot();
  });

  it("renders and matches unhealthy snapshot", async () => {
    getStatus.mockResolvedValue({
      status: "unhealthy",
      version: "test",
    });
    const { container, getByText } = render(<ApiInfo />);
    await waitFor(() =>
      expect(
        getByText("Unable to communicate with API server! Error: unhealthy")
      ).toBeInTheDocument()
    );
    expect(container.firstChild).toMatchSnapshot();
  });
});
